Umbrella
========

.. image:: https://badge.fury.io/py/raincoat-umbrella.svg
    :target: https://pypi.org/pypi/raincoat-umbrella

This package is not very interesting :)

I feel a little bad to upload a "useless" package to the real PyPI, but the
existence of this package will allow writing a much clearer tutorial in the
documentation of `Raincoat <https://pypi.org/pypi/raincoat>`_.

Thank you !

.. image:: https://media.giphy.com/media/3ov9jHDLFzHroRfBT2/giphy.gif

Usage
-----

Launch the command ``umbrella``.

Move and open/close the umbrella with the arrow keys.

Stare at the rain and find you inner peace.

When you're done, quit with ``q``.
